<script setup>
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue';
import ProductFilter from '@/components/ProductFilter.vue'

import { ref, onMounted, computed, reactive } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';

const page = usePage();
console.log(page);
const products = computed(() => page.props.products || []);
const favourites = computed(() => page.props.favourites || []);

const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');
const quantities = reactive({});

const form = useForm({});

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768; // Adjust the threshold as needed
}

onMounted(() => {
    window.addEventListener('resize', handleResize);
    handleResize();

    products.value.forEach(product => {
        quantities[product.id] = 1; // Default quantity
    });
});

const addToFavourite = (product) => {
    const productID = product.id;
    const user_id = page.props.auth.user.id;

    form.post(route('product.favourite',{product_id: productID, user_id: user_id}), {
        onSuccess: () => {
            // Update your success message or perform other actions here
            flashMessage.value = "Product added to favourites!";
        },
        onError: (error) => {
            // Handle error case here, if needed
            console.error(error);
        }
    });
};

const addToCart = (product) => {
    const productID = product.id;
    const user_id = page.props.auth.user.id;
    const quantity = quantities[productID];

    form.post(route('cart.add', {
        id: productID,
        quantity: quantity,
    }), {
        onSuccess: () => {
            flashMessage.value = "Product added to cart!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};
</script>

<template>
    <Head title="Products" />

    <AuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Products</h2>
        </template>

        <div class="py-12 container">
            <div class="row">
                <div v-if="flashMessage" class="col-12 max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                    <div class="form-row mb-6">
                        <div class="col-md-6">
                            <h4>{{ flashMessage }}</h4>
                        </div>
                    </div>
                </div>

                <div class="col-12 col-sm-3 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div class="bg-white overflow-hidden shadow-sm sm:rounded-lg">
                        <ProductFilter></ProductFilter>
                    </div>
                </div>
                <div class="col-12 col-sm-9 max-w-7xl mx-auto sm:px-6 lg:px-8">
                    <div v-if="loading">Loading...</div>
                    <table v-else-if="products && products.length" class="table table-striped">
                        <thead>
                            <tr>
                                <th>Item Number</th>
                                <th v-if="!isMobile">Catalog Desc</th>
                                <th>Price</th>
                                <th>Stock</th>
                                <th>Quantity</th>
                                <th></th>
                                <th></th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr v-for="product in products" :key="product.id">
                                <td>{{ product.item_number }}</td>
                                <td v-if="!isMobile" >{{ product.nags_description }}</td>
                                <td>{{ product.price }}</td>
                                <td :class="product.stock == 1 ? 'text-success' : 'text-danger'">{{ product.stock == 1 ? "In Stock" : "Please Call" }}</td>
                                <td class="cart_qty"><input v-model.number="quantities[product.id]" type="text" :name="`quantity_${product.id}`" id="cart_qty" min="1" /></td>
                                <td><button v-if="product.stock == 1" @click="addToCart(product)">Add to cart</button></td>
                                <td><button @click="addToFavourite(product)">{{ favourites.find(item => item.product_id == product.id) ? "" : "Add to Favourites" }}</button></td>
                            </tr>
                        </tbody>
                    </table>
                    <p v-else>No products found.</p>
                </div>
            </div>
        </div>
    </AuthenticatedLayout>
</template>
<style scoped>
table tr td {
    max-width: 200px;
}
.cart_qty input {
    width: 70px;
    padding: 0 5px;
    height: 33px;
}
</style>
